# ⚡ Flux Programming Language by Splatgames.de ⚡

Flux is a modern programming language developed by [Splatgames.de](https://splatgames.de) to combine simplicity with power, enabling a wide range of applications. Built on top of [Java](https://www.oracle.com/java) with support for [Kotlin](https://kotlinlang.org), Flux offers a familiar and flexible environment for developers of all levels.

Flux is designed to bridge the gap between high-level and low-level programming, making it suitable for tasks ranging from memory management and pointer manipulation to object-oriented and functional programming. Whether you're building complex applications or working on system-level tasks, Flux provides the tools you need.

## ✨ Key Features

- **📝 Intuitive Syntax**: Flux offers a clean and easy-to-learn syntax, inspired by Java and Kotlin.
- **🧑‍💻 Object-Oriented**: Flux fully supports object-oriented programming, including classes, inheritance, and polymorphism.
- **⚙️ Functional Programming**: Leverage higher-order functions and lambda expressions for clean and efficient functional programming.
- **🔧 Manual Memory Management**: Direct control over memory management is provided, with support for pointers and references.
- **🛠️ Low-Level Programming**: Ideal for systems programming, Flux allows for granular control over memory and hardware resources.
- **🚀 High-Level Programming**: Use Flux for complex, high-level application development with object-oriented and functional paradigms.
- **🌐 Cross-Platform**: Flux is designed to run on various operating systems, ensuring wide compatibility and flexibility.

## 🏅 Project Badges

| Badge                                                                     | Description                                                                                                                                                                                        |
|---------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| ![Official](./badges/splatgames_official.svg)          | This badge signifies that the project is officially developed and maintained by Splatgames.de.                                                                                                      |
| ![Team](./badges/splatgames_team.svg)                  | Projects where 20% or more of the contributors are from the Splatgames.de team.                                                                                                                     |
| ![Community](./badges/splatgames_community.svg)        | Community-developed projects that meet Splatgames.de's quality standards but are not officially maintained.                                                                                         |
| ![Experimental](./badges/splatgames_experimental.svg)  | ⚠️ Experimental or unstable projects. These are in active development and may not be suitable for production use.                                                                                   |
| ![Research](./badges/splatgames_research.svg)          | 🔬 Academic and research-focused projects, often maintained by Splatgames.de's research team.                                                                                                        |
| ![Obsolete](./badges/splatgames_obsolete.svg)          | 🗑️ Deprecated projects that are no longer maintained. These may have security vulnerabilities and should not be used in new projects.                                                               |

## 🛠️ Installation

To add Flux to your project, you can integrate it using Maven, Gradle, or other Java-based build tools. Flux is hosted on the [Splatgames.de Nexus Repository](https://nexus.splatgames.de). For setup instructions, visit the [Getting Started](https://flux.splatgames.de/getting-started) page.

## 🤝 Contributing to Flux

We welcome contributions to Flux! Whether it's code, documentation, or feedback, every contribution helps make Flux better. Before contributing, please read our [Contributing Guidelines](https://flux.splatgames.de/contributing) and familiarize yourself with our [Code of Conduct](https://flux.splatgames.de/code-of-conduct).

### 🌟 Contributor Etiquette

We ask all contributors to follow our [Code of Conduct](https://flux.splatgames.de/code-of-conduct) to foster a welcoming and respectful community. Key behaviors we encourage:

- 🙌 Engage authentically and actively to help build a positive community.
- 🤝 Be considerate and respectful in your interactions.
- 🛠️ Strive for collaboration and avoid unnecessary conflict.
- 🚨 Alert community leaders to any concerning behavior or violations of the Code of Conduct.

### 🚫 Unacceptable Behavior

Unacceptable conduct includes, but is not limited to:

- 🚫 Use of sexualized language or imagery, and unwelcome sexual advances.
- ❌ Insults, trolling, or derogatory comments, as well as personal or political attacks.
- 🚷 Public or private harassment.
- 🛑 Sharing private information without permission.
- ❗ Encouraging or advocating for any of the above behaviors.
- 🔁 Repeated harassment or disruptive behavior.

If someone asks you to stop, please stop immediately. For a full list of unacceptable behaviors, refer to the [Code of Conduct](https://flux.splatgames.de/code-of-conduct).

## 📜 License Information

Flux is currently in development and has not yet been released under an open-source license. We are in the process of determining the appropriate licensing model and will update this section once it is finalized. When the first version of Flux (v0.1.0) is released, it will be available under a reliable open-source license.

## 📬 Contact Us

For any inquiries, feedback, or support, feel free to email us at [fluxlang@splatgames.de](mailto:fluxlang@splatgames.de). You can also visit our [Contact Page](https://contact.splatgames.de) for additional information.
